<?php
class ControllerExtensionModuleAnyplace extends Controller {
	private $error = array();

	public function index() {
		$this->load->language('extension/module/anyplace');

		$this->document->setTitle($this->language->get('heading_title'));

		$this->load->model('setting/setting');

		if (($this->request->server['REQUEST_METHOD'] == 'POST') && $this->validate()) {
			$this->model_setting_setting->editSetting('module_anyplace', $this->request->post);

			$this->session->data['success'] = $this->language->get('text_success');

			$this->response->redirect($this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true));
		}

		if (isset($this->error['warning'])) {
			$data['error_warning'] = $this->error['warning'];
		} else {
			$data['error_warning'] = '';
		}


		
		$data['breadcrumbs'] = array();

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_home'),
			'href' => $this->url->link('common/dashboard', 'user_token=' . $this->session->data['user_token'], true)
		);

		$data['breadcrumbs'][] = array(
			'text' => $this->language->get('text_extension'),
			'href' => $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true)
		);

		if (!isset($this->request->get['module_id'])) {
			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('extension/module/anyplace', 'user_token=' . $this->session->data['user_token'], true)
			);
		} else {
			$data['breadcrumbs'][] = array(
				'text' => $this->language->get('heading_title'),
				'href' => $this->url->link('extension/module/anyplace', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id'], true)
			);
		}

		if (!isset($this->request->get['module_id'])) {
			$data['action'] = $this->url->link('extension/module/anyplace', 'user_token=' . $this->session->data['user_token'], true);
		} else {
			$data['action'] = $this->url->link('extension/module/anyplace', 'user_token=' . $this->session->data['user_token'] . '&module_id=' . $this->request->get['module_id'], true);
		}

		$data['cancel'] = $this->url->link('marketplace/extension', 'user_token=' . $this->session->data['user_token'] . '&type=module', true);

		if (isset($this->request->post['module_anyplace_data'])) {
			$data['module_anyplace_data'] = $this->request->post['module_anyplace_data'];
		} elseif($this->config->get('module_anyplace_data')) {
			$data['module_anyplace_data'] = $this->config->get('module_anyplace_data');
		}else{
			$data['module_anyplace_data'] = array();
		}

		if (isset($this->request->post['module_anyplace_symbol_left'])) {
			$data['module_anyplace_symbol_left'] = $this->request->post['module_anyplace_symbol_left'];
		} elseif($this->config->get('module_anyplace_symbol_left')) {
			$data['module_anyplace_symbol_left'] = $this->config->get('module_anyplace_symbol_left');
		}else{
			$data['module_anyplace_symbol_left'] = '##';
		}
		
		if (isset($this->request->post['module_anyplace_symbol_right'])) {
			$data['module_anyplace_symbol_right'] = $this->request->post['module_anyplace_symbol_right'];
		} elseif($this->config->get('module_anyplace_symbol_right')) {
			$data['module_anyplace_symbol_right'] = $this->config->get('module_anyplace_symbol_right');
		}else{
			$data['module_anyplace_symbol_right'] = '##';
		}
		
		if (isset($this->request->post['module_anyplace_status'])) {
			$data['module_anyplace_status'] = $this->request->post['module_anyplace_status'];
		} else {
			$data['module_anyplace_status'] = $this->config->get('module_anyplace_status');
		}
		
		$language = new Language($this->config->get('config_language'));
		
		$this->load->model('setting/module');
		
		$data['ex_modules'] = array();
		
		$records = $this->model_setting_module->getModules();
		
		$names  = array_column($records, 'name');
		array_multisort($names, SORT_ASC, $records);
		
		foreach($records as $record){
			if($record['code']=='anyplace') continue;
			$this->load->language('extension/module/' . $record['code'], 'extension');
			
			$data['ex_modules'][]= array(
				'module_id'		=> $record['module_id'],
				'code'		=> $record['code'],
				'name'		=> $record['name'],
				'fullname'		=> $this->language->get('extension')->get('heading_title'),
			);
		}
		

		

		$data['header'] = $this->load->controller('common/header');
		$data['column_left'] = $this->load->controller('common/column_left');
		$data['footer'] = $this->load->controller('common/footer');

		$this->response->setOutput($this->load->view('extension/module/anyplace', $data));
	}

	protected function validate() {
		if (!$this->user->hasPermission('modify', 'extension/module/anyplace')) {
			$this->error['warning'] = $this->language->get('error_permission');
		}
		
		if (isset($this->request->post['module_anyplace_data'])) {
			foreach($this->request->post['module_anyplace_data'] as $key=>$val){
				if(!$val['module_id']){
					unset($this->request->post['module_anyplace_data'][$key]);
				}
			}
		}

		return !$this->error;
	}
	
	public function install(){
		$this->load->model('setting/event');
		$this->model_setting_event->addEvent('kur1977_anyplace', 'catalog/view/*/*/after', 'extension/module/anyplace/processOutput');
	}
	
	public function uninstall() {
       $this->load->model('setting/event');
       $this->model_setting_event->deleteEventByCode('kur1977_anyplace');
	}
}